﻿/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 * D Port:
 *     Adam Chrapkowski <adam DOT chrapkowski AT gmail DOT com>
 *******************************************************************************/
module printing.Snippet132;
  
/*
 * Printing example snippet: print "Hello World!" in black, outlined in red, to default printer
 *
 * For a list of all SWT example snippets see
 * http://www.eclipse.org/swt/snippets/
 */
 
// dwt
import dwt.DWT;
// dwt.widgets
import dwt.widgets.Display,
       dwt.widgets.MessageBox,
       dwt.widgets.Shell;
// dwt.graphics
import dwt.graphics.Color,
       dwt.graphics.GC,
       dwt.graphics.Rectangle;
// dwt.printing
import dwt.printing.PrintDialog, 
       dwt.printing.Printer, 
       dwt.printing.PrinterData;
// dwthelper
import dwt.dwthelper.utils;

public void 
main(String [] args){
    Display display = new Display();
    Shell shell = new Shell(display);
    shell.open();
    PrinterData data = Printer.getDefaultPrinterData();
    if(data is null){
        MessageBox.showWarning("Warning: No default printer.");
        return;
    }
    Printer printer = new Printer(data);
    if(printer.startJob("DWT Printing Snippet")){
        Color black = printer.getSystemColor(DWT.COLOR_BLACK);
        Color white = printer.getSystemColor(DWT.COLOR_WHITE);
        Color red = printer.getSystemColor(DWT.COLOR_RED);
        Rectangle trim = printer.computeTrim(0, 0, 0, 0);
        Point dpi = printer.getDPI();
        int leftMargin = dpi.x + trim.x; // one inch from left side of paper
        int topMargin = dpi.y / 2 + trim.y; // one-half inch from top edge of paper
        GC gc = new GC(printer);
        if(printer.startPage()){
            gc.setBackground(white);
            gc.setForeground(black);
            String testString = "Hello World!";
            Point extent = gc.stringExtent(testString);
            gc.drawString(testString, leftMargin, topMargin);
            gc.setForeground(red);
            gc.drawRectangle(leftMargin, topMargin, extent.x, extent.y);
            printer.endPage();
        }
        gc.dispose();
        printer.endJob();
    }
    printer.dispose();
    while(!shell.isDisposed()){
      if(!display.readAndDispatch()) display.sleep();
    }
    display.dispose();
}
